@@ -3,6 +3,7 @@
 import typing
 import uuid
 from json import JSONDecodeError
+from simplejson import JSONDecodeError as SimpleJSONDecodeError
 
 import requests
 from logzero import logger
@@ -39,6 +40,10 @@ ENDPOINT_VARIANT_SET_IMPORT_INFO_LIST = (
 )
 #: End point for creating import variant set infos.
 ENDPOINT_VARIANT_SET_IMPORT_INFO_CREATE = ENDPOINT_VARIANT_SET_IMPORT_INFO_LIST
+#: End point for creating import variant set infos.
+ENDPOINT_VARIANT_SET_IMPORT_INFO_UPDATE = (
+    "/importer/api/variant-set-import-info/{case_import_info_uuid}/{variant_set_import_info_uuid}/"
+)
 #: End point for listing BAM QC files.
 ENDPOINT_BAM_QC_FILE_LIST = "/importer/api/bam-qc-file/{case_import_info_uuid}/"
 #: End point for creating BAM QC files.
@@ -74,7 +79,10 @@ ENDPOINT_DB_INFO_FILE_DESTROY = (
 
 
 def case_list(
-    server_url: str, api_token: str, project_uuid: typing.Union[str, uuid.UUID]
+    server_url: str,
+    api_token: str,
+    project_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ) -> typing.List[Case]:
     """Listing of cases from a project UUID."""
     while server_url.endswith("/"):
@@ -82,13 +90,17 @@ def case_list(
     endpoint = "%s%s" % (server_url, ENDPOINT_CASE_LIST.format(project_uuid=project_uuid))
     logger.debug("Sending GET request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.get(endpoint, headers=headers)
+    result = requests.get(endpoint, headers=headers, verify=verify_ssl)
     result.raise_for_status()
     return CONVERTER.structure(result.json(), typing.List[Case])
 
 
 def case_import_info_list(
-    server_url: str, api_token: str, project_uuid: typing.Union[str, uuid.UUID], owner=None
+    server_url: str,
+    api_token: str,
+    project_uuid: typing.Union[str, uuid.UUID],
+    owner=None,
+    verify_ssl: bool = True,
 ) -> typing.List[CaseImportInfo]:
     """Listing case import infos from a project UUID."""
     while server_url.endswith("/"):
@@ -103,14 +115,14 @@ def case_import_info_list(
     else:
         params = None
     logger.debug("Sending GET request to end point %s, params: %s", endpoint, params)
-    result = requests.get(endpoint, headers=headers, params=params)
+    result = requests.get(endpoint, headers=headers, params=params, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -122,6 +134,7 @@ def case_import_info_retrieve(
     api_token: str,
     project_uuid: typing.Union[str, uuid.UUID],
     info_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ) -> CaseImportInfo:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -133,14 +146,14 @@ def case_import_info_retrieve(
     )
     headers = {"Authorization": "Token %s" % api_token}
     logger.debug("Sending GET request to end point %s", endpoint)
-    result = requests.get(endpoint, headers=headers)
+    result = requests.get(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -152,6 +165,7 @@ def case_import_info_create(
     api_token: str,
     project_uuid: typing.Union[str, uuid.UUID],
     data: models.CaseImportInfo,
+    verify_ssl: bool = True,
 ) -> CaseImportInfo:
     """Create new CaseImportInfo on server."""
     while server_url.endswith("/"):
@@ -163,14 +177,16 @@ def case_import_info_create(
     logger.debug("Sending POST request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
     logger.debug("json=%s", CONVERTER.unstructure(data))
-    result = requests.post(endpoint, headers=headers, json=CONVERTER.unstructure(data))
+    result = requests.post(
+        endpoint, headers=headers, json=CONVERTER.unstructure(data), verify=verify_ssl
+    )
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -183,6 +199,7 @@ def case_import_info_update(
     project_uuid: typing.Union[str, uuid.UUID],
     case_import_info_uuid: typing.Union[str, uuid.UUID],
     data: models.CaseImportInfo,
+    verify_ssl: bool = True,
 ) -> CaseImportInfo:
     """Update CaseImportInfo on server."""
     while server_url.endswith("/"):
@@ -196,14 +213,16 @@ def case_import_info_update(
     logger.debug("Sending PUT request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
     logger.debug("json=%s", CONVERTER.unstructure(data))
-    result = requests.put(endpoint, headers=headers, json=CONVERTER.unstructure(data))
+    result = requests.put(
+        endpoint, headers=headers, json=CONVERTER.unstructure(data), verify=verify_ssl
+    )
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -211,7 +230,10 @@ def case_import_info_update(
 
 
 def variant_set_import_info_list(
-    server_url: str, api_token: str, case_import_info_uuid: typing.Union[str, uuid.UUID]
+    server_url: str,
+    api_token: str,
+    case_import_info_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ) -> typing.List[VariantSetImportInfo]:
     """List variant set import infos."""
     while server_url.endswith("/"):
@@ -222,14 +244,14 @@ def variant_set_import_info_list(
     )
     logger.debug("Sending GET request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.get(endpoint, headers=headers)
+    result = requests.get(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -241,6 +263,7 @@ def variant_set_import_info_create(
     api_token: str,
     case_import_info_uuid: typing.Union[str, uuid.UUID],
     data: VariantSetImportInfo,
+    verify_ssl: bool = True,
 ) -> typing.List[VariantSetImportInfo]:
     """Create variant set import info."""
     while server_url.endswith("/"):
@@ -251,14 +274,53 @@ def variant_set_import_info_create(
     )
     logger.debug("Sending POST request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.post(endpoint, headers=headers, json=CONVERTER.unstructure(data))
+    result = requests.post(
+        endpoint, headers=headers, json=CONVERTER.unstructure(data), verify=verify_ssl
+    )
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
+            msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
+        raise RestApiCallException(msg)
+    else:
+        return CONVERTER.structure(result.json(), VariantSetImportInfo)
+
+
+def variant_set_import_info_update(
+    server_url: str,
+    api_token: str,
+    case_import_info_uuid: typing.Union[str, uuid.UUID],
+    variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
+    data: VariantSetImportInfo,
+    verify_ssl: bool = True,
+) -> VariantSetImportInfo:
+    """Create variant set import info."""
+    while server_url.endswith("/"):
+        server_url = server_url[:-1]
+    endpoint = "%s%s" % (
+        server_url,
+        ENDPOINT_VARIANT_SET_IMPORT_INFO_UPDATE.format(
+            case_import_info_uuid=case_import_info_uuid,
+            variant_set_import_info_uuid=variant_set_import_info_uuid,
+        ),
+    )
+    logger.debug("Sending PUT request to end point %s", endpoint)
+    headers = {"Authorization": "Token %s" % api_token}
+    logger.debug("json=%s", CONVERTER.unstructure(data))
+    result = requests.put(
+        endpoint, headers=headers, json=CONVERTER.unstructure(data), verify=verify_ssl
+    )
+    if not result.ok:
+        try:
+            msg = "REST API returned status code %d: %s" % (
+                result.status_code,
+                " ".join([" ".join(v) for v in result.json().values()]),
+            )
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -266,7 +328,10 @@ def variant_set_import_info_create(
 
 
 def bam_qc_file_list(
-    server_url: str, api_token: str, case_import_info_uuid: typing.Union[str, uuid.UUID]
+    server_url: str,
+    api_token: str,
+    case_import_info_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ) -> typing.List[BamQcFile]:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -276,14 +341,14 @@ def bam_qc_file_list(
     )
     logger.debug("Sending GET request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.get(endpoint, headers=headers)
+    result = requests.get(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -296,6 +361,7 @@ def bam_qc_file_upload(
     case_import_info_uuid: typing.Union[str, uuid.UUID],
     data: BamQcFile,
     files: typing.Dict[str, typing.BinaryIO],
+    verify_ssl: bool = True,
 ) -> BamQcFile:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -305,14 +371,16 @@ def bam_qc_file_upload(
     )
     logger.debug("Sending POST request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.post(endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files)
+    result = requests.post(
+        endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files, verify=verify_ssl
+    )
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -324,6 +392,7 @@ def bam_qc_file_destroy(
     api_token: str,
     case_import_info_uuid: typing.Union[str, uuid.UUID],
     bam_qc_file_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ):
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -335,20 +404,23 @@ def bam_qc_file_destroy(
     )
     logger.debug("Sending DELETE request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.delete(endpoint, headers=headers)
+    result = requests.delete(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
 
 
 def genotype_file_list(
-    server_url: str, api_token: str, variant_set_import_info_uuid: typing.Union[str, uuid.UUID]
+    server_url: str,
+    api_token: str,
+    variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ) -> typing.List[GenotypeFile]:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -360,14 +432,14 @@ def genotype_file_list(
     )
     logger.debug("Sending GET request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.get(endpoint, headers=headers)
+    result = requests.get(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -380,6 +452,7 @@ def genotype_file_upload(
     variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
     data: GenotypeFile,
     files: typing.Dict[str, typing.BinaryIO],
+    verify_ssl: bool = True,
 ) -> GenotypeFile:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -391,14 +464,16 @@ def genotype_file_upload(
     )
     logger.debug("Sending POST request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.post(endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files)
+    result = requests.post(
+        endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files, verify=verify_ssl
+    )
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -410,6 +485,7 @@ def genotype_file_destroy(
     api_token: str,
     variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
     genotype_file_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ):
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -422,20 +498,23 @@ def genotype_file_destroy(
     )
     logger.debug("Sending DELETE request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.delete(endpoint, headers=headers)
+    result = requests.delete(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
 
 
 def effects_file_list(
-    server_url: str, api_token: str, variant_set_import_info_uuid: typing.Union[str, uuid.UUID]
+    server_url: str,
+    api_token: str,
+    variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ) -> typing.List[EffectsFile]:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -447,14 +526,14 @@ def effects_file_list(
     )
     logger.debug("Sending GET request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.get(endpoint, headers=headers)
+    result = requests.get(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -467,6 +546,7 @@ def effects_file_upload(
     variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
     data: EffectsFile,
     files: typing.Dict[str, typing.BinaryIO],
+    verify_ssl: bool = True,
 ) -> EffectsFile:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -478,14 +558,16 @@ def effects_file_upload(
     )
     logger.debug("Sending POST request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.post(endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files)
+    result = requests.post(
+        endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files, verify=verify_ssl
+    )
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -497,6 +579,7 @@ def effects_file_destroy(
     api_token: str,
     variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
     effects_file_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ):
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -509,20 +592,23 @@ def effects_file_destroy(
     )
     logger.debug("Sending DELETE request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.delete(endpoint, headers=headers)
+    result = requests.delete(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
 
 
 def db_info_file_list(
-    server_url: str, api_token: str, variant_set_import_info_uuid: typing.Union[str, uuid.UUID]
+    server_url: str,
+    api_token: str,
+    variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ) -> typing.List[DatabaseInfoFile]:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -534,14 +620,14 @@ def db_info_file_list(
     )
     logger.debug("Sending GET request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.get(endpoint, headers=headers)
+    result = requests.get(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -554,6 +640,7 @@ def db_info_file_upload(
     variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
     data: DatabaseInfoFile,
     files: typing.Dict[str, typing.BinaryIO],
+    verify_ssl: bool = True,
 ) -> DatabaseInfoFile:
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -565,14 +652,16 @@ def db_info_file_upload(
     )
     logger.debug("Sending POST request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.post(endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files)
+    result = requests.post(
+        endpoint, headers=headers, data=CONVERTER.unstructure(data), files=files, verify=verify_ssl
+    )
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
                 result.status_code,
                 " ".join([" ".join(v) for v in result.json().values()]),
             )
-        except JSONDecodeError:
+        except (JSONDecodeError, SimpleJSONDecodeError):
             msg = "REST API returned status code %d: %s" % (result.status_code, result.content)
         raise RestApiCallException(msg)
     else:
@@ -584,6 +673,7 @@ def db_info_file_destroy(
     api_token: str,
     variant_set_import_info_uuid: typing.Union[str, uuid.UUID],
     db_info_file_uuid: typing.Union[str, uuid.UUID],
+    verify_ssl: bool = True,
 ):
     while server_url.endswith("/"):
         server_url = server_url[:-1]
@@ -596,7 +686,7 @@ def db_info_file_destroy(
     )
     logger.debug("Sending DELETE request to end point %s", endpoint)
     headers = {"Authorization": "Token %s" % api_token}
-    result = requests.delete(endpoint, headers=headers)
+    result = requests.delete(endpoint, headers=headers, verify=verify_ssl)
     if not result.ok:
         try:
             msg = "REST API returned status code %d: %s" % (
